pub struct DotMarkup { /* fields omitted */ }Expand description
A code block with Dot markup.
use subplot::{GraphMarkup, DotMarkup};
let markup = r#"digraph "foo" { a -> b }"#;
let svg = DotMarkup::new(&markup).as_svg().unwrap();
assert!(svg.len() > 0);
Convert the markup into an SVG.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,